@@ -1,5 +1,5 @@
 /*
-# copyright (C) 2013 FUJITSU LIMITED All Rights Reserved
+# copyright (C) 2013-2014 FUJITSU LIMITED All Rights Reserved
 
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -1260,6 +1260,11 @@ int main(int argc, char **argv)
 	int	flg = 0;
 	int	r;
 
+	if (geteuid() != 0) {
+		fprintf(stderr, "error: Because you are not root, you cannot execute this command. \n");
+		exit(-1);
+	}
+	
 	if (argc < 3) {
 		usage();
 	}
